==> haskell-haddock-library-1.5.0.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: z-haddock-library-z-attoparsec
version: 1.5.0.1
package-name: haddock-library
lib-name: attoparsec
id: haddock-library-1.5.0.1-5xCLIHKTqOk4YzRkLo6mc3-attoparsec
key: haddock-library-1.5.0.1-5xCLIHKTqOk4YzRkLo6mc3-attoparsec
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 9dd2edd5ff4f43d29c57f88f56203883
exposed-modules:
    Data.Attoparsec.ByteString Data.Attoparsec.ByteString.Char8
    Data.Attoparsec.Combinator
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Internal.Types
                Data.Attoparsec.Number
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-5xCLIHKTqOk4YzRkLo6mc3-attoparsec
depends:
    base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.5.0.1
id: haddock-library-1.5.0.1-GdV4wUFTVFeIpTSX9rklyd
key: haddock-library-1.5.0.1-GdV4wUFTVFeIpTSX9rklyd
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: f97b9e137cea93e49b7e6d1ba17d79db
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-GdV4wUFTVFeIpTSX9rklyd
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    transformers-0.5.5.0
    haddock-library-1.5.0.1-5xCLIHKTqOk4YzRkLo6mc3-attoparsec
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             haddock-library-1.5.0.1-5xCLIHKTqOk4YzRkLo6mc3-attoparsec=9dd2edd5ff4f43d29c57f88f56203883
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-library-1.5.0.1-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: z-haddock-library-z-attoparsec
version: 1.5.0.1
package-name: haddock-library
lib-name: attoparsec
id: haddock-library-1.5.0.1-Ap8jGnxUWl2HWq0N3dnEOj-attoparsec
key: haddock-library-1.5.0.1-Ap8jGnxUWl2HWq0N3dnEOj-attoparsec
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 16af9cb228114b08b9ed3969db4b648a
exposed-modules:
    Data.Attoparsec.ByteString Data.Attoparsec.ByteString.Char8
    Data.Attoparsec.Combinator
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Internal.Types
                Data.Attoparsec.Number
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-Ap8jGnxUWl2HWq0N3dnEOj-attoparsec
depends:
    base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.5.0.1
id: haddock-library-1.5.0.1-6c1Is8Q7xrc5y88Tkf9tCy
key: haddock-library-1.5.0.1-6c1Is8Q7xrc5y88Tkf9tCy
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 648b40b0193b05a9acfda4c9641240f7
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.5.0.1
hs-libraries: HShaddock-library-1.5.0.1-6c1Is8Q7xrc5y88Tkf9tCy
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    transformers-0.5.5.0
    haddock-library-1.5.0.1-Ap8jGnxUWl2HWq0N3dnEOj-attoparsec
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             haddock-library-1.5.0.1-Ap8jGnxUWl2HWq0N3dnEOj-attoparsec=16af9cb228114b08b9ed3969db4b648a
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
